@@ -320,12 +320,12 @@ enum [[deprecated]] : int {
     SBK_QT3DRENDER_QVIEWPORT_IDX                             = 354,
     SBK_QT3DRENDER_QWAITFENCE_HANDLETYPE_IDX                 = 358,
     SBK_QT3DRENDER_QWAITFENCE_IDX                            = 356,
-    SBK_QSHAREDPOINTER_QT3DRENDER_QTEXTUREIMAGEDATA_IDX      = 360, // QSharedPointer<Qt3DRender::QTextureImageData>
-    SBK_QSHAREDPOINTER_CONSTQT3DRENDER_QTEXTUREIMAGEDATA_IDX = 360, // (const)
+    SBK_QSHAREDPOINTER_QT3DRENDER_PROPERTYREADERINTERFACE_IDX = 360, // QSharedPointer<Qt3DRender::PropertyReaderInterface>
+    SBK_QSHAREDPOINTER_CONSTQT3DRENDER_PROPERTYREADERINTERFACE_IDX = 360, // (const)
     SBK_QSHAREDPOINTER_QT3DRENDER_QTEXTUREIMAGEDATAGENERATOR_IDX = 362, // QSharedPointer<Qt3DRender::QTextureImageDataGenerator>
     SBK_QSHAREDPOINTER_CONSTQT3DRENDER_QTEXTUREIMAGEDATAGENERATOR_IDX = 362, // (const)
-    SBK_QSHAREDPOINTER_QT3DRENDER_PROPERTYREADERINTERFACE_IDX = 364, // QSharedPointer<Qt3DRender::PropertyReaderInterface>
-    SBK_QSHAREDPOINTER_CONSTQT3DRENDER_PROPERTYREADERINTERFACE_IDX = 364, // (const)
+    SBK_QSHAREDPOINTER_QT3DRENDER_QTEXTUREIMAGEDATA_IDX      = 364, // QSharedPointer<Qt3DRender::QTextureImageData>
+    SBK_QSHAREDPOINTER_CONSTQT3DRENDER_QTEXTUREIMAGEDATA_IDX = 364, // (const)
     SBK_QT3DRENDER_IDX_COUNT                                 = 366,
 };
 
@@ -510,18 +510,21 @@ enum : int {
     SBK_Qt3DRender_QViewport_IDX                             = 177,
     SBK_Qt3DRender_QWaitFence_HandleType_IDX                 = 179,
     SBK_Qt3DRender_QWaitFence_IDX                            = 178,
-    SBK_QSharedPointer_Qt3DRender_QTextureImageData_IDX      = 180, // QSharedPointer<Qt3DRender::QTextureImageData>
-    SBK_QSharedPointer_constQt3DRender_QTextureImageData_IDX = 180, // (const)
+    SBK_QSharedPointer_Qt3DRender_PropertyReaderInterface_IDX = 180, // QSharedPointer<Qt3DRender::PropertyReaderInterface>
+    SBK_QSharedPointer_constQt3DRender_PropertyReaderInterface_IDX = 180, // (const)
     SBK_QSharedPointer_Qt3DRender_QTextureImageDataGenerator_IDX = 181, // QSharedPointer<Qt3DRender::QTextureImageDataGenerator>
     SBK_QSharedPointer_constQt3DRender_QTextureImageDataGenerator_IDX = 181, // (const)
-    SBK_QSharedPointer_Qt3DRender_PropertyReaderInterface_IDX = 182, // QSharedPointer<Qt3DRender::PropertyReaderInterface>
-    SBK_QSharedPointer_constQt3DRender_PropertyReaderInterface_IDX = 182, // (const)
+    SBK_QSharedPointer_Qt3DRender_QTextureImageData_IDX      = 182, // QSharedPointer<Qt3DRender::QTextureImageData>
+    SBK_QSharedPointer_constQt3DRender_QTextureImageData_IDX = 182, // (const)
     SBK_Qt3DRender_IDX_COUNT                                 = 183,
 };
 
 // This variable stores all Python types exported by this module.
 extern Shiboken::Module::TypeInitStruct *SbkPySide6_Qt3DRenderTypeStructs;
 
+// This variable stores all Python types exported by this module in a backwards compatible way with identical indexing.
+[[deprecated]] extern PyTypeObject **SbkPySide6_Qt3DRenderTypes;
+
 // This variable stores the Python module object exported by this module.
 extern PyObject *SbkPySide6_Qt3DRenderModuleObject;
 
@@ -531,55 +534,45 @@ extern SbkConverter **SbkPySide6_Qt3DRenderTypeConverters;
 // Converter indices
 enum [[deprecated]] : int {
     SBK_QT3DRENDER_QLIST_INT_IDX                             = 0, // QList<int>
-    SBK_QT3DRENDER_QLIST_QT3DCORE_QENTITYPTR_IDX             = 2, // QList<Qt3DCore::QEntity*>
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QRAYCASTERHIT_IDX        = 4, // QList<Qt3DRender::QRayCasterHit>
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QLAYERPTR_IDX            = 6, // QList<Qt3DRender::QLayer*>
-    SBK_QT3DRENDER_QLIST_QOBJECTPTR_IDX                      = 8, // QList<QObject*>
-    SBK_QT3DRENDER_QLIST_QBYTEARRAY_IDX                      = 10, // QList<QByteArray>
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QABSTRACTTEXTUREIMAGEPTR_IDX = 12, // QList<Qt3DRender::QAbstractTextureImage*>
-    SBK_QT3DRENDER_QLIST_QT3DCORE_QNODEPTR_IDX               = 14, // QList<Qt3DCore::QNode*>
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QFILTERKEYPTR_IDX        = 16, // QList<Qt3DRender::QFilterKey*>
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QPARAMETERPTR_IDX        = 18, // QList<Qt3DRender::QParameter*>
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QRENDERSTATEPTR_IDX      = 20, // QList<Qt3DRender::QRenderState*>
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QSORTPOLICY_SORTTYPE_IDX = 22, // QList<Qt3DRender::QSortPolicy::SortType>
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QRENDERTARGETOUTPUTPTR_IDX = 24, // QList<Qt3DRender::QRenderTargetOutput*>
-    SBK_QT3DRENDER_QLIST_QT3DCORE_QCOMPONENTPTR_IDX          = 26, // QList<Qt3DCore::QComponent*>
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QTECHNIQUEPTR_IDX        = 28, // QList<Qt3DRender::QTechnique*>
-    SBK_QT3DRENDER_QLIST_QREAL_IDX                           = 30, // QList<qreal>
-    SBK_QT3DRENDER_STD_VECTOR_QSHAREDPOINTER_QT3DCORE_QASPECTJOB_IDX = 32, // std::vector<QSharedPointer< Qt3DCore::QAspectJob>>
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QRENDERPASSPTR_IDX       = 34, // QList<Qt3DRender::QRenderPass*>
-    SBK_QT3DRENDER_QLIST_QSHAREDPOINTER_QT3DRENDER_QTEXTUREIMAGEDATA_IDX = 36, // QList<QSharedPointer< Qt3DRender::QTextureImageData>>
-    SBK_QT3DRENDER_QLIST_QVARIANT_IDX                        = 38, // QList<QVariant>
-    SBK_QT3DRENDER_QLIST_QSTRING_IDX                         = 40, // QList<QString>
-    SBK_QT3DRENDER_QMAP_QSTRING_QVARIANT_IDX                 = 42, // QMap<QString,QVariant>
-    SBK_QT3DRENDER_CONVERTERS_IDX_COUNT                      = 44,
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QRAYCASTERHIT_IDX        = 1, // QList<Qt3DRender::QRayCasterHit>
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QLAYERPTR_IDX            = 2, // QList<Qt3DRender::QLayer*>
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QABSTRACTTEXTUREIMAGEPTR_IDX = 3, // QList<Qt3DRender::QAbstractTextureImage*>
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QFILTERKEYPTR_IDX        = 4, // QList<Qt3DRender::QFilterKey*>
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QPARAMETERPTR_IDX        = 5, // QList<Qt3DRender::QParameter*>
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QRENDERSTATEPTR_IDX      = 6, // QList<Qt3DRender::QRenderState*>
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QSORTPOLICY_SORTTYPE_IDX = 7, // QList<Qt3DRender::QSortPolicy::SortType>
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QRENDERTARGETOUTPUTPTR_IDX = 8, // QList<Qt3DRender::QRenderTargetOutput*>
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QTECHNIQUEPTR_IDX        = 9, // QList<Qt3DRender::QTechnique*>
+    SBK_QT3DRENDER_QLIST_QREAL_IDX                           = 10, // QList<qreal>
+    SBK_QT3DRENDER_STD_VECTOR_QSHAREDPOINTER_QT3DCORE_QASPECTJOB_IDX = 11, // std::vector<QSharedPointer<Qt3DCore::QAspectJob>>
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QRENDERPASSPTR_IDX       = 12, // QList<Qt3DRender::QRenderPass*>
+    SBK_QT3DRENDER_QLIST_QSHAREDPOINTER_QT3DRENDER_QTEXTUREIMAGEDATA_IDX = 13, // QList<QSharedPointer<Qt3DRender::QTextureImageData>>
+    SBK_QT3DRENDER_QLIST_QVARIANT_IDX                        = 14, // QList<QVariant>
+    SBK_QT3DRENDER_QLIST_QSTRING_IDX                         = 15, // QList<QString>
+    SBK_QT3DRENDER_QMAP_QSTRING_QVARIANT_IDX                 = 16, // QMap<QString,QVariant>
+    SBK_QT3DRENDER_CONVERTERS_IDX_COUNT                      = 17,
 };
 
 // Converter indices
 enum : int {
     SBK_Qt3DRender_QList_int_IDX                             = 0, // QList<int>
-    SBK_Qt3DRender_QList_Qt3DCore_QEntityPTR_IDX             = 1, // QList<Qt3DCore::QEntity*>
-    SBK_Qt3DRender_QList_Qt3DRender_QRayCasterHit_IDX        = 2, // QList<Qt3DRender::QRayCasterHit>
-    SBK_Qt3DRender_QList_Qt3DRender_QLayerPTR_IDX            = 3, // QList<Qt3DRender::QLayer*>
-    SBK_Qt3DRender_QList_QObjectPTR_IDX                      = 4, // QList<QObject*>
-    SBK_Qt3DRender_QList_QByteArray_IDX                      = 5, // QList<QByteArray>
-    SBK_Qt3DRender_QList_Qt3DRender_QAbstractTextureImagePTR_IDX = 6, // QList<Qt3DRender::QAbstractTextureImage*>
-    SBK_Qt3DRender_QList_Qt3DCore_QNodePTR_IDX               = 7, // QList<Qt3DCore::QNode*>
-    SBK_Qt3DRender_QList_Qt3DRender_QFilterKeyPTR_IDX        = 8, // QList<Qt3DRender::QFilterKey*>
-    SBK_Qt3DRender_QList_Qt3DRender_QParameterPTR_IDX        = 9, // QList<Qt3DRender::QParameter*>
-    SBK_Qt3DRender_QList_Qt3DRender_QRenderStatePTR_IDX      = 10, // QList<Qt3DRender::QRenderState*>
-    SBK_Qt3DRender_QList_Qt3DRender_QSortPolicy_SortType_IDX = 11, // QList<Qt3DRender::QSortPolicy::SortType>
-    SBK_Qt3DRender_QList_Qt3DRender_QRenderTargetOutputPTR_IDX = 12, // QList<Qt3DRender::QRenderTargetOutput*>
-    SBK_Qt3DRender_QList_Qt3DCore_QComponentPTR_IDX          = 13, // QList<Qt3DCore::QComponent*>
-    SBK_Qt3DRender_QList_Qt3DRender_QTechniquePTR_IDX        = 14, // QList<Qt3DRender::QTechnique*>
-    SBK_Qt3DRender_QList_qreal_IDX                           = 15, // QList<qreal>
-    SBK_Qt3DRender_std_vector_QSharedPointer_Qt3DCore_QAspectJob_IDX = 16, // std::vector<QSharedPointer< Qt3DCore::QAspectJob>>
-    SBK_Qt3DRender_QList_Qt3DRender_QRenderPassPTR_IDX       = 17, // QList<Qt3DRender::QRenderPass*>
-    SBK_Qt3DRender_QList_QSharedPointer_Qt3DRender_QTextureImageData_IDX = 18, // QList<QSharedPointer< Qt3DRender::QTextureImageData>>
-    SBK_Qt3DRender_QList_QVariant_IDX                        = 19, // QList<QVariant>
-    SBK_Qt3DRender_QList_QString_IDX                         = 20, // QList<QString>
-    SBK_Qt3DRender_QMap_QString_QVariant_IDX                 = 21, // QMap<QString,QVariant>
-    SBK_Qt3DRender_CONVERTERS_IDX_COUNT                      = 22,
+    SBK_Qt3DRender_QList_Qt3DRender_QRayCasterHit_IDX        = 1, // QList<Qt3DRender::QRayCasterHit>
+    SBK_Qt3DRender_QList_Qt3DRender_QLayerPTR_IDX            = 2, // QList<Qt3DRender::QLayer*>
+    SBK_Qt3DRender_QList_Qt3DRender_QAbstractTextureImagePTR_IDX = 3, // QList<Qt3DRender::QAbstractTextureImage*>
+    SBK_Qt3DRender_QList_Qt3DRender_QFilterKeyPTR_IDX        = 4, // QList<Qt3DRender::QFilterKey*>
+    SBK_Qt3DRender_QList_Qt3DRender_QParameterPTR_IDX        = 5, // QList<Qt3DRender::QParameter*>
+    SBK_Qt3DRender_QList_Qt3DRender_QRenderStatePTR_IDX      = 6, // QList<Qt3DRender::QRenderState*>
+    SBK_Qt3DRender_QList_Qt3DRender_QSortPolicy_SortType_IDX = 7, // QList<Qt3DRender::QSortPolicy::SortType>
+    SBK_Qt3DRender_QList_Qt3DRender_QRenderTargetOutputPTR_IDX = 8, // QList<Qt3DRender::QRenderTargetOutput*>
+    SBK_Qt3DRender_QList_Qt3DRender_QTechniquePTR_IDX        = 9, // QList<Qt3DRender::QTechnique*>
+    SBK_Qt3DRender_QList_qreal_IDX                           = 10, // QList<qreal>
+    SBK_Qt3DRender_std_vector_QSharedPointer_Qt3DCore_QAspectJob_IDX = 11, // std::vector<QSharedPointer<Qt3DCore::QAspectJob>>
+    SBK_Qt3DRender_QList_Qt3DRender_QRenderPassPTR_IDX       = 12, // QList<Qt3DRender::QRenderPass*>
+    SBK_Qt3DRender_QList_QSharedPointer_Qt3DRender_QTextureImageData_IDX = 13, // QList<QSharedPointer<Qt3DRender::QTextureImageData>>
+    SBK_Qt3DRender_QList_QVariant_IDX                        = 14, // QList<QVariant>
+    SBK_Qt3DRender_QList_QString_IDX                         = 15, // QList<QString>
+    SBK_Qt3DRender_QMap_QString_QVariant_IDX                 = 16, // QMap<QString,QVariant>
+    SBK_Qt3DRender_CONVERTERS_IDX_COUNT                      = 17,
 };
 // Macros for type check
 
@@ -767,9 +760,9 @@ template<> inline PyTypeObject *SbkType< ::Qt3DRender::QTextureWrapMode >() { re
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QViewport >() { return Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QViewport_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QWaitFence::HandleType >() { return Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QWaitFence_HandleType_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QWaitFence >() { return Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QWaitFence_IDX]); }
-template<> inline PyTypeObject *SbkType< ::QSharedPointer<Qt3DRender::QTextureImageData> >() { return Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_QSharedPointer_Qt3DRender_QTextureImageData_IDX]); }
-template<> inline PyTypeObject *SbkType< ::QSharedPointer<Qt3DRender::QTextureImageDataGenerator> >() { return Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_QSharedPointer_Qt3DRender_QTextureImageDataGenerator_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSharedPointer<Qt3DRender::PropertyReaderInterface> >() { return Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_QSharedPointer_Qt3DRender_PropertyReaderInterface_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QSharedPointer<Qt3DRender::QTextureImageDataGenerator> >() { return Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_QSharedPointer_Qt3DRender_QTextureImageDataGenerator_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QSharedPointer<Qt3DRender::QTextureImageData> >() { return Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_QSharedPointer_Qt3DRender_QTextureImageData_IDX]); }
 
 } // namespace Shiboken
 
