@@ -6,8 +6,8 @@ from types import ModuleType
 
 # __all__ is computed below.
 __pre_all__ = ["QtCore", "QtGui", "QtWidgets", "QtPrintSupport", "QtSql", "QtNetwork", "QtTest", "QtConcurrent", "QtDesigner", "QtXml", "QtHelp", "QtMultimedia", "QtMultimediaWidgets", "QtOpenGL", "QtOpenGLWidgets", "QtPositioning", "QtLocation", "QtNetworkAuth", "QtNfc", "QtQml", "QtQuick", "QtQuick3D", "QtQuickControls2", "QtQuickTest", "QtQuickWidgets", "QtScxml", "QtSensors", "QtSerialPort", "QtSerialBus", "QtStateMachine", "QtTextToSpeech", "QtCharts", "QtSpatialAudio", "QtSvg", "QtSvgWidgets", "QtDataVisualization", "QtGraphs", "QtGraphsWidgets", "QtBluetooth", "QtUiTools", "QtAxContainer", "QtWebChannel", "QtWebSockets", "QtHttpServer", "Qt3DCore", "Qt3DRender", "Qt3DInput", "Qt3DLogic", "Qt3DAnimation", "Qt3DExtras"]
-__version__ = "6.9.2"
-__version_info__ = (6, 9, 2, "", "")
+__version__ = "6.10.0"
+__version_info__ = (6, 10, 0, "", "")
 
 SKIP_MYPY_TEST = bool("")
 
@@ -64,9 +64,9 @@ def _setupQtDirectories():
         #              setting dictates. There is no longer a difference in path structure.
         global Shiboken
         from shiboken6 import Shiboken
-    except Exception:
+    except Exception as e:
         paths = ', '.join(sys.path)
-        print(f"PySide6/__init__.py: Unable to import Shiboken from {paths}",
+        print(f"PySide6/__init__.py: Unable to import Shiboken from {paths}: {e}",
               file=sys.stderr)
         raise
 
